# package_name
> some text
> Storing at: PyPI url

## Install
```bash
pip install blah blah
```

# help links:

nbdev template: https://github.com/fastai/nbdev_template
example of nbs_build_lib: https://youtu.be/r4RuVI-r5ZI
how to ssh git clone: https://youtu.be/5Ck07BJDXTE


# CREDS:

PyPI: maxim_denisov Zenit1925Zenit1925
Gitlab: maxim_denisov Zenit1925Zenit1925
